# rind

[![CI](https://github.com/astrofrog/rind/actions/workflows/ci.yml/badge.svg)](https://github.com/astrofrog/rind/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/astrofrog/rind/branch/main/graph/badge.svg)](https://codecov.io/gh/astrofrog/rind)
[![Documentation Status](https://readthedocs.org/projects/rind/badge/?version=latest)](https://rind.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://img.shields.io/pypi/v/rind.svg)](https://pypi.org/project/rind/)
[![Python versions](https://img.shields.io/pypi/pyversions/rind.svg)](https://pypi.org/project/rind/)
[![License](https://img.shields.io/pypi/l/rind.svg)](https://github.com/astrofrog/rind/blob/main/LICENSE)

> **Warning**
> This package is experimental and under active development. The API may change without notice.

A minimal [PEP 517](https://peps.python.org/pep-0517/) build backend to make
it easy to create a **metapackage** that extends
a core package by installing additional dependencies.

See the [documentation](https://rind.readthedocs.io) for information on how to use this package.
